WindowAssigner

Trait WindowAssigner 

pub trait WindowAssigner{
    // Required method
    fn assign_windows(
        &self,
        timestamp: u64,
        context: WindowAssignerContext,
    ) -> Vec<Window>;
}
A WindowAssigner assigns zero or more Windows to an element.

Required Methods

fn assign_windows( &self, timestamp: u64, context: WindowAssignerContext, ) -> Vec<Window>

Returns a collection of windows that should be assigned to the element.

Implementors