pub trait WindowAssigner{
// Required method
fn assign_windows(
&self,
timestamp: u64,
context: WindowAssignerContext,
) -> Vec<Window>;
}Expand description
A WindowAssigner assigns zero or more Windows to an element.
Required Methods
Sourcefn assign_windows(
&self,
timestamp: u64,
context: WindowAssignerContext,
) -> Vec<Window>
fn assign_windows( &self, timestamp: u64, context: WindowAssignerContext, ) -> Vec<Window>
Returns a collection of windows that should be assigned to the element.